@@ -53,8 +53,18 @@ int SoapySDRDevice_unmake(SoapySDRDevice *device)
 SoapySDRDevice **SoapySDRDevice_make_list(const SoapySDRKwargs *argsList, const size_t length)
 {
     __SOAPY_SDR_C_TRY
+    auto outDevices = callocArrayType<SoapySDRDevice *>(length);
     const auto devices = SoapySDR::Device::make(toKwargsList(argsList, length));
-    auto outDevices = (SoapySDRDevice **)calloc(length, sizeof(SoapySDRDevice *));
+    for (size_t i = 0; i < length; i++) outDevices[i] = (SoapySDRDevice *)devices[i];
+    return outDevices;
+    __SOAPY_SDR_C_CATCH_RET(nullptr);
+}
+
+SoapySDRDevice **SoapySDRDevice_make_listStrArgs(const char* const *argsList, const size_t length)
+{
+    __SOAPY_SDR_C_TRY
+    auto outDevices = callocArrayType<SoapySDRDevice *>(length);
+    const auto devices = SoapySDR::Device::make(toStringVector(argsList, length));
     for (size_t i = 0; i < length; i++) outDevices[i] = (SoapySDRDevice *)devices[i];
     return outDevices;
     __SOAPY_SDR_C_CATCH_RET(nullptr);
@@ -65,7 +75,7 @@ int SoapySDRDevice_unmake_list(SoapySDRDevice **devices, const size_t length)
     __SOAPY_SDR_C_TRY
     std::vector<SoapySDR::Device *> devicesVector(length);
     for (size_t i = 0; i < length; i++) devicesVector[i] = (SoapySDR::Device *)devices[i];
-    free(devices);
+    SoapySDR_free(devices);
     SoapySDR::Device::unmake(devicesVector);
     __SOAPY_SDR_C_CATCH
 }
